@@ -28,7 +28,7 @@ def main( ) :
     """
     name_package = 'cressp'
     dir_remote = 'https://github.com/ahs2202/cressp2/raw/main/cressp/' # remote directory from which datafiles will be downloaded
-    dir_folder_cressp = pkg_resources.resource_filename( name_package, '' )
+    dir_folder_cressp = f'{pkg_resources.resource_filename( name_package, '' )}/' # directory of the current installed package
     
     
     """
